// #include "ros/ros.h"
// #include "std_msgs/String.h"

// class DummyTalker
// {
// public:
//     DummyTalker() : count_(0)
//     {
//         nh_ = ros::NodeHandle("~");
//         publisher_ = nh_.advertise<std_msgs::String>("chatter", 10);
//         timer_ = nh_.createTimer(ros::Duration(0.5), &DummyTalker::publish_message, this);
//     }

// private:
//     void publish_message(const ros::TimerEvent&)
//     {
//         std_msgs::String message;
//         message.data = "I am talking";
//         ROS_INFO("Publishing: '%s'", message.data.c_str());
//         publisher_.publish(message);
//     }

//     ros::NodeHandle nh_;
//     ros::Publisher publisher_;
//     ros::Timer timer_;
//     size_t count_;
// };

// int main(int argc, char **argv)
// {
//     ros::init(argc, argv, "dummy_talker");
//     DummyTalker talker;
//     ros::spin();
//     return 0;
// }


#include "ros/ros.h"
#include "custom_bridge_msgs/CustomState.h"
#include "custom_bridge_msgs/State.h"

int PUBLISH_RATE = 1;

class DummyPublisher
{
    public:
        DummyPublisher() : publish_rate_(PUBLISH_RATE) // Rate of 10 Hz
        {
            // Advertise the topic with a queue size of 10
            publisher_ = nh_.advertise<custom_bridge_msgs::CustomState>("custom_state_topic", PUBLISH_RATE);
        }

        void publishLoop()
        {
            while (ros::ok())
            {
                std::vector<double> reward_vector{1., 2., 3., 4., 5.};
                custom_bridge_msgs::State state;
                custom_bridge_msgs::CustomState custom_state;
                state.value = 2;
                state.rewards = reward_vector;
                custom_state.state = state;
                publisher_.publish(custom_state);

                ros::spinOnce();
                publish_rate_.sleep();
            }
        }

    private:
        ros::NodeHandle nh_;
        ros::Publisher publisher_;
        ros::Rate publish_rate_; // Rate object to control the publish frequency
};

int main(int argc, char **argv)
{
    ros::init(argc, argv, "dummy_publisher");
    DummyPublisher dummyPublisher;
    dummyPublisher.publishLoop();
    return 0;
}