#include "rclcpp/rclcpp.hpp"
#include "custom_bridge_msgs/msg/custom_state.hpp" // Adjust the include path to your ROS 2 message definition

class DummySubscriber : public rclcpp::Node
{
public:
    DummySubscriber() : Node("dummy_subscriber")
    {
        subscriber_ = this->create_subscription<custom_bridge_msgs::msg::CustomState>(
            "custom_state_topic", 10,
            std::bind(&DummySubscriber::topic_callback, this, std::placeholders::_1));
    }

private:
    void topic_callback(const custom_bridge_msgs::msg::CustomState::SharedPtr msg) const
    {
        RCLCPP_INFO_STREAM(this->get_logger(), "Received state value: " << msg->state.value);
        for (int reward : msg->state.rewards)
        {
            RCLCPP_INFO_STREAM(this->get_logger(), "reward: " << reward);
        }
    }

    rclcpp::Subscription<custom_bridge_msgs::msg::CustomState>::SharedPtr subscriber_;
};

int main(int argc, char *argv[])
{
    rclcpp::init(argc, argv);
    rclcpp::spin(std::make_shared<DummySubscriber>());
    rclcpp::shutdown();
    return 0;
}
