#include "rclcpp/rclcpp.hpp"
#include <nav_msgs/msg/path.hpp>
#include "custom_bridge_msgs/srv/custom_service_two.hpp"

class DummyCustomServiceTwo : public rclcpp::Node
{
public:
    DummyCustomServiceTwo() : Node("custom_service_topic")
    {
        service_ = this->create_service<custom_bridge_msgs::srv::CustomServiceTwo>(
            "custom_service_topic",
            std::bind(&DummyCustomServiceTwo::service_callback, this, std::placeholders::_1, std::placeholders::_2));
    }

private:
    void service_callback(
        const std::shared_ptr<custom_bridge_msgs::srv::CustomServiceTwo::Request> request,
        std::shared_ptr<custom_bridge_msgs::srv::CustomServiceTwo::Response> response)
    {
        RCLCPP_INFO_STREAM(this->get_logger(), "Received CustomServiceTwo request (empty), populating response obj");
        response->success = true;
        response->reward = 10.0;
        response->iterations = 200;
        response->path = nav_msgs::msg::Path();

        response->path.header.frame_id = "map";
        response->path.header.stamp = this->get_clock()->now();

    }

    rclcpp::Service<custom_bridge_msgs::srv::CustomServiceTwo>::SharedPtr service_;
};

int main(int argc, char *argv[])
{
    rclcpp::init(argc, argv);
    auto node = std::make_shared<DummyCustomServiceTwo>();
    rclcpp::spin(node);
    rclcpp::shutdown();
    return 0;
}
